//	+---------------------------+
//	|	Server Weather			|
//	+---------------------------+
//	|	Version: 2.0			|
//	|	Released: Jan 17, 2014	|
//	|	Author: Zapk | 12270	|
//	+---------------------------+

if(!isObject(Server_Weather))
{
	new AIConnection(Server_Weather)
	{
		isAdmin = 1;
		isSuperAdmin = 1;
	};
}

if(!isObject(Server_Weather_Rain))
{
	datablock AudioProfile(Server_Weather_Rain)
	{
		filename = "./rain.wav";
		description = AudioClosest3d;
		preload = false;
	};
	datablock AudioProfile(Server_Weather_Snow)
	{
		filename = "./snow.wav";
		description = AudioClosest3d;
		preload = false;
	};
	datablock AudioProfile(Server_Weather_Thunder1)
	{
		filename = "./thunder1.wav";
		description = AudioClosest3d;
		preload = false;
	};
	datablock AudioProfile(Server_Weather_Thunder2)
	{
		filename = "./thunder2.wav";
		description = AudioClosest3d;
		preload = false;
	};
	datablock AudioProfile(Server_Weather_Thunder3)
	{
		filename = "./thunder3.wav";
		description = AudioClosest3d;
		preload = false;
	};
	datablock AudioProfile(Server_Weather_Thunder4)
	{
		filename = "./thunder4.wav";
		description = AudioClosest3d;
		preload = false;
	};
}

function Server_Weather()
{
	exec( "./server.cs" );
}

function Server_Weather_FixWater()
{
	waterPlane.setTransform("0 0 -0.5 1 0 0 0");
	waterZone.setScale("1000000 1000000 1000");
	waterZone.setTransform("-500000 500000 -1000 1 0 0 0");
	waterPlane.sendUpdate();
}

function Server_Weather_SetWater(%height)
{
	waterPlane.setTransform("0 0" SPC %height - 0.5 SPC "1 0 0 0");
	waterZone.setTransform("-500000 500000" SPC %height - 1000 SPC "1 0 0 0");
	waterPlane.sendUpdate();
}

function serverCmdWeather(%this, %type)
{
	if(%this.isSuperAdmin)
	{
		if(isFunction(%func = "WeatherType" @ %type))
		{
			call(%func);
		}
		else
		{
			messageClient(%this, '', "\c6Unknown weather type.");
		}
	}
	else
	{
		messageClient(%this, '', "\c6You must be \c4Super Admin \c6to change the weather.");
	}
}

function Server_Weather_Cancel()
{
	setWater("NONE");
	setGround("Add-Ons/Ground_Plate/plate.ground");
	cancel($Server_Weather::ThunderLoop);
	cancel($Server_Weather::PuddleLoop);
}

function WeatherTypeStorm()
{
	Server_Weather_Cancel();
	
	if(isObject(Server_Weather_Ambience))
	{
		Server_Weather_Ambience.delete();
	}
	
	setSkyBox("Add-Ons/Sky_Slate_Storm/Slate_Storm.dml");
	setWater("Add-Ons/Water_Brick/brick.water");
	Server_Weather_FixWater();
	Server_Weather_SetWater(-1);
	
	new AudioEmitter(Server_Weather_Ambience)
	{
		position = "-1.25972 -0.189093 0";
		profile = "Server_Weather_Rain";
		useProfileDescription = "0";
		description = "AudioLooping2D";
		type = "0";
		volume = "1";
		outsideAmbient = "1";
		ReferenceDistance = "4";
		maxDistance = "100";
		isLooping = "1";
		loopCount = "-1";
		minLoopGap = "0";
		maxLoopGap = "0";
		enableVisualFeedback = "1";
		is3D = "0";
		coneInsideAngle = "360";
		coneOutsideAngle = "360";
		coneOutsideVolume = "1";
		coneVector = "-8.74228e-008 -1 0";
	};
	announce("\c6It is now \c4Raining\c6.");
	
	if(getRandom(0, 1))
	{
		$Server_Weather::ThunderLoop = schedule(getRandom(1000, 20000), 0, ThunderLoop);
		announce("  \c6- There is also \c4Thunder\c6 and \c4Lightning\c6.");
	}
	
	if(getRandom(0, 6) > 4)
	{
		schedule(1000, 0, PuddleLoop);
		announce("  \c6- There may also be small amounts of flooding.");
	}
}

if(isPackage(Server_Weather))
{
	deactivatePackage(Server_Weather);
}

package Server_Weather
{
	function serverCmdEnvGui_SetVar(%this, %type, %val, %val2)
	{
		Parent::serverCmdEnvGui_SetVar(%this, %type, %val, %val2);
		echo("ENV_GUI: Set " @ %type @ " to " @ %val SPC %val2);
	}
};

activatePackage(Server_Weather);

function WeatherTypeClear()
{
	Server_Weather_Cancel();
	setSkyBox("Add-Ons/Sky_Skylands/Skylands.dml");
	
	if(isObject(Server_Weather_Ambience))
	{
		Server_Weather_Ambience.delete();
	}
	announce("\c6It is now \c4Clear\c6.");
}

function WeatherTypeSnow()
{
	Server_Weather_Cancel();
	setSkyBox("Add-Ons/Sky_Spooky3/Spooky3Snow.dml");
	
	groundPlane.color = "230 230 230 255";
	groundPlane.sendUpdate();
	
	if(isObject(Server_Weather_Ambience))
	{
		Server_Weather_Ambience.delete();
	}
	
	new AudioEmitter(Server_Weather_Ambience)
	{
		position = "-1.25972 -0.189093 0";
		profile = "Server_Weather_Snow";
		useProfileDescription = "0";
		description = "AudioLooping2D";
		type = "0";
		volume = "1";
		outsideAmbient = "1";
		ReferenceDistance = "4";
		maxDistance = "100";
		isLooping = "1";
		loopCount = "-1";
		minLoopGap = "0";
		maxLoopGap = "0";
		enableVisualFeedback = "1";
		is3D = "0";
		coneInsideAngle = "360";
		coneOutsideAngle = "360";
		coneOutsideVolume = "1";
		coneVector = "-8.74228e-008 -1 0";
	};
	announce("\c6It is now \c4Snowing\c6.");
}

function ThunderLoop()
{
	cancel($Server_Weather::ThunderLoop);
	
	lightning();
	thunder();
	
	$Server_Weather::ThunderLoop = schedule(getRandom(5000, 30000), 0, ThunderLoop);
}

function PuddleLoop(%a)
{
	cancel($Server_Weather::PuddleLoop);
	
	if(%a > 1)
	{
		return;
	}
	
	Server_Weather_SetWater(%a);
	
	$Server_Weather::PuddleLoop = schedule(1000 + (200 * %a), 0, PuddleLoop, %a + 0.001);
}

function lightning(%a)
{
	if(%a > 1)
	{
		return;
	}
	//Sun.color = "1 1 1 1";
	//Sun.ambient = "1 1 1 1";
	//Sun.shadowColor = "1 1 1 1";
	//Sun.sendUpdate();
	setSkyBox("Add-Ons/Sky_Blank/white.dml");
	
	schedule(%r = getRandom(100, 200), 0, setSkybox, "Add-Ons/Sky_Slate_Storm/Slate_Storm.dml");
	schedule(%r + 100, 0, lightning, %a++);
}

function thunder()
{
	ServerPlay2D("Server_Weather_Thunder" @ getRandom(1, 2));
}

schedule(0, 0, WeatherTypeClear);